import { Logger } from '../logger';
import { z } from 'zod';
import { WorkflowLogMessage, StepId, StepDefinition } from './types';
/**
 * Workflow engine that manages the execution of sequential steps
 * with variable resolution and state management
 */
export declare class Workflow {
    private name;
    private logger?;
    /** Array of configured workflow steps */
    private steps;
    /** Optional schema for validating initial trigger data */
    triggerSchema?: z.ZodType<any>;
    /** XState machine instance that orchestrates the workflow execution */
    private machine;
    /**
     * Creates a new Workflow instance
     * @param name - Unique identifier for the workflow
     * @param logger - Optional logger instance for workflow events
     */
    constructor(name: string, logger?: Logger<WorkflowLogMessage> | undefined);
    /**
     * Internal logging helper that formats and sends logs to the configured logger
     * @param level - Severity level of the log
     * @param message - Main log message
     * @param data - Optional data to include in the log
     * @param stepId - Optional ID of the step that generated the log
     */
    private log;
    /**
     * Initializes the XState machine that powers the workflow
     * Configures actions, actors, and initial state
     * @returns The created XState machine
     */
    private initializeMachine;
    /**
     * Creates the state configuration for the XState machine
     * Defines the states, transitions, and actions for each workflow step
     * @returns Record of state configurations
     */
    private createStates;
    /**
     * Sets the schema for validating trigger data
     * @param schema - Zod schema for trigger data validation
     * @returns this instance for method chaining
     */
    setTriggerSchema(schema: z.ZodType<any>): this;
    /**
     * Type guard to check if a value is a valid VariableReference
     * @param value - Value to check
     * @returns True if value is a VariableReference
     */
    private isVariableReference;
    /**
     * Creates a validated step ID, ensuring uniqueness within the workflow
     * @param id - Proposed step ID
     * @returns The validated and branded step ID
     * @throws Error if ID is invalid or duplicate
     */
    createStepId(id: string): StepId;
    /**
     * Adds a new step to the workflow
     * @param id - Unique identifier for the step
     * @param config - Step configuration including handler, schema, variables, and payload
     * @returns this instance for method chaining (builder pattern baybyyyy)
     * @throws Error if step ID is duplicate or variable resolution fails
     */
    addStep<TSchema extends z.ZodType<any>>(id: string, config: StepDefinition<TSchema>): this;
    /**
     * Resolves variables for a step from trigger data or previous step results
     * @param stepConfig - Configuration of the step needing variable resolution
     * @param context - Current workflow context containing results and trigger data
     * @returns Object containing resolved variable values
     * @throws Error if variable resolution fails
     */
    private resolveVariables;
    /**
     * Executes the workflow with the given trigger data
     * @param triggerData - Initial data to start the workflow with
     * @returns Promise resolving to workflow results or rejecting with error
     * @throws Error if trigger schema validation fails
     */
    executeWorkflow<TSchema = unknown, TTrigger = this['triggerSchema'] extends z.ZodSchema<infer T> ? T : TSchema>(triggerData?: TTrigger): Promise<{
        triggerData?: TTrigger;
        results: Record<string, unknown>;
    }>;
    /**
     * Evaluates a single condition against workflow context
     */
    private evaluateCondition;
}
/**
 * TODO:
 * - Add retry mechanisms for failed steps
 * - Add validation for circular dependencies in variable references
 * - Add support for logging step durations
 * - Add support for step hooks (before/after)
 * - Add workflow execution history
 * - Better types (remove all the any's)
 */
//# sourceMappingURL=index.d.ts.map